Index: webrtc/api/objc/RTCSessionDescription+Private.h |
diff --git a/webrtc/api/objc/RTCIceCandidate+Private.h b/webrtc/api/objc/RTCSessionDescription+Private.h |
similarity index 51% |
copy from webrtc/api/objc/RTCIceCandidate+Private.h |
copy to webrtc/api/objc/RTCSessionDescription+Private.h |
index feb3898e5d5a523f3989647aaf19300753c09e06..7eca1ac3ec958f8e51f78c4fb5648a40c6af192d 100644 |
--- a/webrtc/api/objc/RTCIceCandidate+Private.h |
+++ b/webrtc/api/objc/RTCSessionDescription+Private.h |
@@ -8,27 +8,29 @@ |
* be found in the AUTHORS file in the root of the source tree. |
*/ |
-#import "RTCIceCandidate.h" |
+#import "RTCSessionDescription.h" |
-#include "webrtc/base/scoped_ptr.h" |
#include "talk/app/webrtc/jsep.h" |
NS_ASSUME_NONNULL_BEGIN |
-@interface RTCIceCandidate () |
+@interface RTCSessionDescription () |
/** |
* The native IceCandidateInterface representation of this RTCIceCandidate |
* object. This is needed to pass to the underlying C++ APIs. |
*/ |
@property(nonatomic, readonly) |
- rtc::scoped_ptr<webrtc::IceCandidateInterface> nativeCandidate; |
+ webrtc::SessionDescriptionInterface *nativeDescription; |
/** |
* Initialize an RTCIceCandidate from a native IceCandidateInterface. No |
* ownership is taken of the native candidate. |
*/ |
-- (instancetype)initWithCandidate:(webrtc::IceCandidateInterface *)candidate; |
+- (instancetype)initWithDescription:(webrtc::SessionDescriptionInterface *) |
tkchin_webrtc
2016/01/05 16:29:18
ditto break after :
hjon
2016/01/05 22:16:20
Done.
|
+ description; |
@end |
@@ -8,27 +8,29 @@ |
/** |
- * The native IceCandidateInterface representation of this RTCIceCandidate |
- * object. This is needed to pass to the underlying C++ APIs. |
+ * The native SessionDescriptionInterface representation of this |
+ * RTCSessionDescription object. This is needed to pass to the underlying C++ |
+ * APIs. |
*/ |
@@ -8,27 +8,29 @@ |
/** |
- * Initialize an RTCIceCandidate from a native IceCandidateInterface. No |
- * ownership is taken of the native candidate. |
+ * Initialize an RTCSessionDescription from a native |
+ * SessionDescriptionInterface. No ownership is taken of the native session |
+ * description. |
*/ |